.. include:: ../BADGES.rst

Command Line
============

Help::

    hspfbintoolbox --help

about
~~~~~
.. program-output:: hspfbintoolbox about --help
   :prompt:

catalog
~~~~~~~
.. program-output:: hspfbintoolbox catalog --help
   :prompt:

extract
~~~~~~~
.. program-output:: hspfbintoolbox extract --help
   :prompt:
